@@ -396,8 +396,8 @@ class TestTimeStamper:
     @freeze_time("1980-03-25 16:00:00")
     def test_local(self):
         """
-        Timestamp in local timezone work.  We can't add a timezone to the
-        string without additional libraries.
+        Timestamp in local timezone work. Due to historic reasons, the default
+        format does not include a timezone.
         """
         ts = TimeStamper(fmt="iso", utc=False)
         d = ts(None, None, {})
@@ -414,6 +414,17 @@ class TestTimeStamper:
 
         assert "1980" == d["timestamp"]
 
+    @freeze_time("1980-03-25 16:00:00")
+    def test_tz_aware(self):
+        """
+        The timestamp that is used for formatting is timezone-aware.
+        """
+        ts = TimeStamper(fmt="%z")
+        d = ts(None, None, {})
+
+        assert "" == datetime.datetime.now().strftime("%z")  # noqa: DTZ005
+        assert "" != d["timestamp"]
+
     @freeze_time("1980-03-25 16:00:00")
     def test_adds_Z_to_iso(self):
         """
@@ -514,12 +525,12 @@ class TestFormatExcInfo:
 
     def test_formats_tuple(self):
         """
-        If exc_info is a tuple, it is used.
+        If exc_info is an arbitrary 3-tuple, it is not used.
         """
         formatter = ExceptionRenderer(lambda exc_info: exc_info)
         d = formatter(None, None, {"exc_info": (None, None, 42)})
 
-        assert {"exception": (None, None, 42)} == d
+        assert {} == d
 
     def test_gets_exc_info_on_bool(self):
         """
@@ -580,6 +591,4 @@ class TestFormatExcInfo:
         """
         A missing exception does not blow up.
         """
-        assert {"exception": "MISSING"} == format_exc_info(
-            None, None, {"exc_info": ei}
-        )
+        assert {} == format_exc_info(None, None, {"exc_info": ei})
